==> Do-1.60.tar.gz: Do-1.60/lib/Data/Object/Regexp/Func.pm <==
package Data::Object::Regexp::Func;

use 5.014;

use strict;
use warnings;

use Data::Object 'Class';

extends 'Data::Object::Func';

our $VERSION = '1.60'; # VERSION

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Regexp::Func

=cut

=head1 ABSTRACT

Functions for RegexpRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Regexp::Func;

=cut

=head1 DESCRIPTION

Data::Object::Regexp::Func is an abstract base class for function classes in
the Data::Object::Regexp::Func space.

=cut

=head1 INHERITANCE

This package inherits behaviors from:

L<Data::Object::Func>

=cut

=head1 LIBRARIES

This package uses type constraints defined by:

L<Data::Object::Library>

=cut

=head1 CREDITS

Al Newkirk, C<awncorp@cpan.org>, C<+284>

Anthony Brummett, C<abrummet@genome.wustl.edu>, C<+10>

=cut

=head1 AUTHOR

Al Newkirk, C<awncorp@cpan.org>

=head1 LICENSE

Copyright (C) 2011-2019, Al Newkirk, et al.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.

=head1 PROJECT

L<GitHub|https://github.com/iamalnewkirk/do>

L<Projects|https://github.com/iamalnewkirk/do/projects>

L<Milestones|https://github.com/iamalnewkirk/do/milestones>

L<Contributing|https://github.com/iamalnewkirk/do/blob/master/CONTRIBUTE.mkdn>

L<Issues|https://github.com/iamalnewkirk/do/issues>

=head1 SEE ALSO

To get the most out of this distribution, consider reading the following:

L<Do>

L<Data::Object>

L<Data::Object::Class>

L<Data::Object::ClassHas>

L<Data::Object::Role>

L<Data::Object::RoleHas>

L<Data::Object::Library>

=cut

==> Do-1.70.tar.gz: Do-1.70/lib/Data/Object/Regexp/Func.pm <==
package Data::Object::Regexp::Func;

use 5.014;

use strict;
use warnings;

use Data::Object 'Class';

extends 'Data::Object::Func';

our $VERSION = '1.70'; # VERSION

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Regexp::Func

=cut

=head1 ABSTRACT

Functions for RegexpRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Regexp::Func;

=cut

=head1 DESCRIPTION

Data::Object::Regexp::Func is an abstract base class for function classes in
the Data::Object::Regexp::Func space.

=cut

=head1 INHERITANCE

This package inherits behaviors from:

L<Data::Object::Func>

=cut

=head1 LIBRARIES

This package uses type constraints defined by:

L<Data::Object::Library>

=cut

=head1 CREDITS

Al Newkirk, C<+287>

Anthony Brummett, C<+10>

=cut

=head1 AUTHOR

Al Newkirk, C<awncorp@cpan.org>

=head1 LICENSE

Copyright (C) 2011-2019, Al Newkirk, et al.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.

=head1 PROJECT

L<GitHub|https://github.com/iamalnewkirk/do>

L<Projects|https://github.com/iamalnewkirk/do/projects>

L<Milestones|https://github.com/iamalnewkirk/do/milestones>

L<Contributing|https://github.com/iamalnewkirk/do/blob/master/CONTRIBUTE.mkdn>

L<Issues|https://github.com/iamalnewkirk/do/issues>

=head1 SEE ALSO

To get the most out of this distribution, consider reading the following:

L<Do>

L<Data::Object>

L<Data::Object::Class>

L<Data::Object::ClassHas>

L<Data::Object::Role>

L<Data::Object::RoleHas>

L<Data::Object::Library>

=cut
